#
# spec file for package python-pytest-bdd
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-pytest-bdd
Version:        7.3.0
Release:        1.4
Summary:        BDD for pytest
License:        MIT
URL:            https://github.com/pytest-dev/pytest-bdd
Source:         https://github.com/pytest-dev/pytest-bdd/archive/%{version}.tar.gz#/pytest-bdd-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Mako
Requires:       python-packaging
Requires:       python-parse
Requires:       python-parse_type
Requires:       python-pytest >= 6.2.0
Requires:       python-typing_extensions
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Mako}
BuildRequires:  %{python_module execnet}
BuildRequires:  %{python_module packaging}
BuildRequires:  %{python_module parse_type}
BuildRequires:  %{python_module parse}
BuildRequires:  %{python_module pytest >= 6.2.0}
BuildRequires:  %{python_module typing_extensions}
%python_subpackages

%description
BDD library for the py.test runner

pytest-bdd implements a subset of Gherkin language for the automation of the project
requirements testing and easier behavioral driven development.

Unlike many other BDD tools it doesn't require a separate runner and benefits from
the power and flexibility of the pytest. It allows to unify your unit and functional
tests, easier continuous integration server configuration and maximal reuse of the
tests setup.

Pytest fixtures written for the unit tests can be reused for the setup and actions
mentioned in the feature steps with dependency injection, which allows a true BDD
just-enough specification of the requirements without maintaining any context object
containing the side effects of the Gherkin imperative declarations.

%prep
%setup -q -n pytest-bdd-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%python_clone -a %{buildroot}%{_bindir}/pytest-bdd

%check
export LANG=en_US.UTF-8
%{python_expand #  provide the u-a controlled command in PATH
mkdir -p build/testbin
ln -s %{buildroot}%{_bindir}/pytest-bdd-%{$python_bin_suffix} build/testbin/pytest-bdd
}
export PATH=$PWD/build/testbin:$PATH
%pytest

%post
%python_install_alternative pytest-bdd

%postun
%python_uninstall_alternative pytest-bdd

%files %{python_files}
%doc AUTHORS.rst CHANGES.rst README.rst
%license LICENSE.txt
%python_alternative %{_bindir}/pytest-bdd
%{python_sitelib}/pytest_bdd
%{python_sitelib}/pytest_bdd-%{version}.dist-info

%changelog
* Tue Oct  1 2024 Dirk Müller <dmueller@suse.com>
- update to 7.3.0:
  * Fix an issue when only the first Step would inject a fixture,
    while later steps would not be able to.
  * Test against the latest versions of pytest (8.2, 8.3).
* Fri Jun  7 2024 Dirk Müller <dmueller@suse.com>
- update to 7.2.0:
  * Fix compatibility issue with Python 3.13.
  * Declare compatibility with Python 3.13.
* Mon May  6 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 7.1.2:
  * Address another compatibility issue with pytest 8.1 (fixture registration).
  * Address a bug introduced in pytest-bdd 7.1 caused by incorrect pytest
    version check.
  * Address compatibility issue with pytest 8.1.
  * Fix errors occurring if `pytest_unconfigure` is called before
    `pytest_configure`.
  * parsers.re now does a fullmatch instead of a partial match. This is to
    make it work just like the other parsers, since they don't ignore
    non-matching characters at the end of the string.
  * Drop python 3.7 compatibility, as it's no longer supported.
  * Declare official support for python 3.12
  * Improve parser performance by 15%%
  * Fix regression introduced in version 6.1.0 where the
    pytest_bdd_after_scenario hook would be called after every step instead
    of after the scenario.
  * Fix bug where steps without parsers would take precedence over steps
    with parsers.
  * Step functions can now be decorated multiple times with @given, @when,
    @then. Previously every decorator would override converters and
    target_fixture every at every application.
  * Require pytest>=6.2
  * Using modern way to specify hook options to avoid deprecation warnings
    with pytest >=7.2.
  * Add generic step decorator that will be used for all kind of steps
  * Add stacklevel param to given, when, then, step decorators. This allows
    for programmatic step generation
  * Hide pytest-bdd internal method in user tracebacks
  * Make the package PEP 561-compatible
  * Configuration option bdd_features_base_dir is interpreted as relative
    to the pytest root directory.
  * Fix regression introduced in 6.0.0 where a step function decorated
    multiple using a parsers times would not be executed correctly.
  * Step arguments are no longer fixtures
  * Drop support of python 3.6, pytest 4
  * Step definitions can have "yield" statements again (4.0 release broke
    it). They will be executed as normal fixtures: code after the yield is
    executed during teardown of the test.
  * pytest_bdd.parsers.StepParser now is an Abstract Base Class. Subclasses
    must make sure to implement the abstract methods.
- Switch to pyproject macros.
- No more greedy globs in %%files.
* Fri Mar 11 2022 Steve Kowalik <steven.kowalik@suse.com>
- Update to 5.0.0:
  * Rewrite the logic to parse Examples for Scenario Outlines. Now the
    substitution of the examples is done during the parsing of Gherkin
    feature files.
  * Removed ``example_converters`` from ``scenario(...)`` signature.
  * Removed ``--cucumberjson-expanded`` and ``--cucumber-json-expanded``
    options. Now the JSON report is always expanded.
  * Removed ``--gherkin-terminal-reporter-expanded`` option.
  * `when` and `then` steps now can provide a `target_fixture`, just like
    `given` does.
  * Drop compatibility for python 2 and officially support only python >= 3.6.
  * Fix error when using `--cucumber-json-expanded` in combination with
    `example_converters` (marcbrossaissogeti).
  * Fix `--generate-missing` not correctly recognizing steps with parsers
- Drop python-mock and python-six from BuildRequires and Requires.
- No longer skip tests that are not broken
* Fri Feb 26 2021 Ben Greiner <code@bnavigator.de>
- update to 4.0.2
  * Fix a bug that prevents using comments in the Examples:
    section. (youtux)
- provide the correct u-a conrolled command to the tests
- Skip failing tests: test_at_scenario and test_step_trace
* Wed Sep 23 2020 Ondřej Súkup <mimi.vx@gmail.com>
- update to 4.0.1
- remove requires on python-enum34, not needed by pytest-bdd
  * Fixed performance regression introduced in 4.0.0 where collection time
    of tests would take way longer than before
  * Strict Gherkin option is removed (@scenario() does not accept
    the strict_gherkin parameter).
  * @scenario() does not accept the undocumented parameter caller_module anymore.
  * Given step is no longer a fixture. The scope parameter is also removed.
  * Fixture parameter is removed from the given step declaration.
  * pytest_bdd_step_validation_error hook is removed.
  * Fix an error with pytest-pylint plugin
  * Fix pytest-xdist 2.0 compatibility
  * Fix compatibility with pytest 6 --import-mode=importlib option.
* Tue Jun  9 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.4.0:
  * Parse multiline steps according to the gherkin specification #365.
* Mon Apr 27 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.3.0:
  * Require at least pytest 4.3
- Remove merged test_flaky.patch
* Mon Apr 20 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build without python2
* Tue Mar 10 2020 Ondřej Súkup <mimi.vx@gmail.com>
- use %%pytest macro
- add test_flaky.patch to fix gerkhin reporter test flakinness
* Mon Sep  9 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.2.1:
  * python 3.8 support
* Thu Jul 18 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.1.1:
  * Allow unicode string in @given() step names when using python2. This makes the transition of projects from python 2 to 3 easier.
* Thu Mar 21 2019 John Vandenberg <jayvdb@gmail.com>
- Convert to single spec
- Use %%license
- Update to v3.1.0
* Sat Jan 18 2014 toms@opensuse.org
- Initial version 0.6.8
